The SICD structure elements (sarpy.io.complex.sicd_elements)
============================================================

.. toctree::
    :maxdepth: 1
    :caption: Contents:

    sicd
    collection_info
    image_creation
    image_data
    geo_data
    grid
    timeline
    position
    radar_collection
    image_formation
    scpcoa
    radiometric
    antenna
    error_statistics
    match_info
    rg_az_comp
    pfa
    rma
    blocks
